pyramid_caching
###############

.. image:: https://travis-ci.org/hadrien/pyramid_caching.png?branch=master
   :target: https://travis-ci.org/hadrien/pyramid_caching

.. image:: https://coveralls.io/repos/hadrien/pyramid_caching/badge.png
   :target: https://coveralls.io/r/hadrien/pyramid_caching

.. image:: https://pypip.in/d/pyramid_caching/badge.png
   :target: https://crate.io/packages/pyramid_caching/


Key versioning caching for pyramid.
